-
+
Fun
@@ -605,6 +621,9 @@
+
+
+
diff --git a/app/service-worker.js b/app/service-worker.js
index 2416f3e..945030d 100644
--- a/app/service-worker.js
+++ b/app/service-worker.js
@@ -37,7 +37,7 @@
/* eslint-disable indent, no-unused-vars, no-multiple-empty-lines, max-nested-callbacks, space-before-function-paren, quotes, comma-spacing */
'use strict';
-var precacheConfig = [["FiraCode.ttf","fa1f8c8961adca519738d9518139579c"],["changelog.html","7f40f4b9a97ca60826e7ad09e401d570"],["icon-48.png","ca68956f464ed4fd2e09c66d5edaed5f"],["index.html","f3ec1c4674416008e2fc3f0ca10882a0"],["lib/atomizer.browser.js","451f56bc105c5ad333445998b3c085a2"],["lib/babel-polyfill.min.js","60977959048c0f5ef5aa66d6eac61eb3"],["lib/babel.min.js","77a1a84bbc2661db874c738f9b3ba375"],["lib/code-blast.js","48f8f054be45d3ad5054a7c7f87be0ff"],["lib/codemirror/mode/coffeescript/coffeescript.js","dea87b9f4c669789c4760605d947f1a9"],["lib/codemirror/mode/css/css.js","6c9ca32a78c120340e588ed3df734138"],["lib/codemirror/mode/css/gss.html","9afa6e2f3a7daa6127a3f26e2e68005c"],["lib/codemirror/mode/css/gss_test.js","e40c6fd9abdc6edc2b29e521bda726e1"],["lib/codemirror/mode/css/less.html","a35ff50857d48bb2f4df8ac737f35d64"],["lib/codemirror/mode/css/scss.html","8c96251f27727a9b23b45c41511e23a0"],["lib/codemirror/mode/haml/haml.js","9abc1679e0f54dcdd62d2326ed6133f5"],["lib/codemirror/mode/htmlembedded/htmlembedded.js","67f745ab3879bf7bc3029ac75ea3e181"],["lib/codemirror/mode/htmlmixed/htmlmixed.js","2d6915b576f267e93f0e1cf72f31af37"],["lib/codemirror/mode/javascript/javascript.js","3b2f1591e3175a24846cb182943f2a40"],["lib/codemirror/mode/javascript/json-ld.html","a2a5069194b78b6b5523cace263cab06"],["lib/codemirror/mode/javascript/typescript.html","76c2ffb883a133aa0fc5cc75ec0c56f5"],["lib/codemirror/mode/jsx/jsx.js","7bee6944931c2cc6ccd99b50fca637db"],["lib/codemirror/mode/markdown/markdown.js","30dd4984e2e929429d70cf5174b35c5d"],["lib/codemirror/mode/meta.js","6e456ea5fd8920c85d5281bd1efecb4c"],["lib/codemirror/mode/pug/pug.js","e988fd72c82f3b11836f6a06f7452436"],["lib/codemirror/mode/sass/sass.js","bd31ac70e9a457abc2789c2b83a21984"],["lib/codemirror/mode/stylus/stylus.js","81e2d281ecbb1dcf5c86857097ae60a7"],["lib/codemirror/mode/xml/xml.js","80f64aaafa6af7844d14f32f3219bb26"],["lib/codemirror/theme/3024-day.css","73c8f41583b4b71dbe1e5eac5c96f1a9"],["lib/codemirror/theme/3024-night.css","745180be9a932f24c6c0dd4ebdf5a0ed"],["lib/codemirror/theme/abcdef.css","8004cb71fd65e58bdfa64fdd55241315"],["lib/codemirror/theme/ambiance-mobile.css","256f2dd130b80c6afaa40fddf700d12a"],["lib/codemirror/theme/ambiance.css","6a200e1f3976929816cf3ac4675c810a"],["lib/codemirror/theme/base16-dark.css","84b6347918411d58d7f9b65a7ee87f65"],["lib/codemirror/theme/base16-light.css","037c7f3d16fe6d5ae2baa532e334172b"],["lib/codemirror/theme/base2tone-meadow-dark.css","f9dd12e2e51fc1575c57f3e5edc2232f"],["lib/codemirror/theme/bespin.css","cc414e4ec18bc89b3c79935b0e27fc20"],["lib/codemirror/theme/blackboard.css","cf9366960ff65c8101793bc64fe13e88"],["lib/codemirror/theme/cobalt.css","3488b576456693fd7ced2da0e10c8a16"],["lib/codemirror/theme/colorforth.css","b2ee8d2296277fc2811a7473ee4e9977"],["lib/codemirror/theme/dracula.css","e514d652ae86bfeaed34237b7d3afe44"],["lib/codemirror/theme/duotone-dark.css","02ec891b23125aaf625d978a39fd24ca"],["lib/codemirror/theme/duotone-light.css","608d11459665117d708651ce7f803fde"],["lib/codemirror/theme/eclipse.css","194369eec66630cfaf662ce5f0a193be"],["lib/codemirror/theme/elegant.css","0a4227e805a9d5f73a55dd248c1b052d"],["lib/codemirror/theme/erlang-dark.css","b5543f5273c968449760ab0d6a2af6dc"],["lib/codemirror/theme/hopscotch.css","b924ed31af30b1c68e5a01fc3c9b0553"],["lib/codemirror/theme/icecoder.css","576d776abdf7e28ea9f84e2eb161a20d"],["lib/codemirror/theme/isotope.css","7bb44bff5190c427de5ae750d6369633"],["lib/codemirror/theme/lesser-dark.css","da2c896bff035cec86fa98b6dc13f7cc"],["lib/codemirror/theme/liquibyte.css","9f37e7a4f3c02bec9bb735b78ed082d6"],["lib/codemirror/theme/material.css","11e812a3688805b5c187a6e6852bafe1"],["lib/codemirror/theme/mbo.css","55ff4bdd8a92c3dcbfd5421c532b3059"],["lib/codemirror/theme/mdn-like.css","79f8dabc5593d01d27bc824b801f9f05"],["lib/codemirror/theme/midnight.css","950e76dca6461ee1a2eac39f2d886613"],["lib/codemirror/theme/monokai.css","31c75ebee6311d49c046ffbbb91028f4"],["lib/codemirror/theme/neat.css","6b19894b9787c6791c250a95d0d4f8d6"],["lib/codemirror/theme/neo.css","2886072b53043c167e6f8765606c705c"],["lib/codemirror/theme/night.css","fe3ce7650a77e7e3887816dd7b6d880d"],["lib/codemirror/theme/panda-syntax.css","acbf94261e43c1f29c2252eb445de032"],["lib/codemirror/theme/paraiso-dark.css","3c24cee0dfac767713840b24e8359c99"],["lib/codemirror/theme/paraiso-light.css","e245bbfd22b4f61efe526ff13903f19e"],["lib/codemirror/theme/pastel-on-dark.css","48aae1a42733db57bd0a260ce0d83975"],["lib/codemirror/theme/railscasts.css","a5e7682d89da46244e5464d9572e24d8"],["lib/codemirror/theme/rubyblue.css","52bb601017a90bca522d66f6e82e73aa"],["lib/codemirror/theme/seti.css","f71668880eb1625f420ceaad670436f0"],["lib/codemirror/theme/solarized dark.css","4d05a166d713bb1ac24833061c1522d7"],["lib/codemirror/theme/solarized light.css","4d05a166d713bb1ac24833061c1522d7"],["lib/codemirror/theme/the-matrix.css","33c49ceeedafd0a08e712e465e3ad3ce"],["lib/codemirror/theme/tomorrow-night-bright.css","777d36e1c5bbfeb3bf2ca8dd607eee93"],["lib/codemirror/theme/tomorrow-night-eighties.css","5ceb5531fbe074d5190b55e8c725051e"],["lib/codemirror/theme/ttcn.css","d2cb74dfae563a10e9c286357429ea8b"],["lib/codemirror/theme/twilight.css","684040adf66ef89355cb7ebc6b54b00b"],["lib/codemirror/theme/vibrant-ink.css","f10004836fb29cc9a08c987d3e18938a"],["lib/codemirror/theme/xq-dark.css","60f162f0c4240e7352364d436b5598fa"],["lib/codemirror/theme/xq-light.css","447e80da7fe8c5c2bcf39127200cead2"],["lib/codemirror/theme/yeti.css","623dc805bc84dd6d25deef376593354e"],["lib/codemirror/theme/zenburn.css","94ad50bf3d048ed92cc513cd901dc685"],["lib/coffee-script.js","a43664b71b7b96e90046a605f6fa51a1"],["lib/emmet.js","6fff639e42ec8c00f4f4ff30b52e60df"],["lib/esprima.js","dfe041b0a8a5dda5c62ed8d2a1d3a666"],["lib/hint.min.css","0dc51e410a460622949f927dfda1bc32"],["lib/inlet.css","8242884724cfac965b53cf0a3d774c0b"],["lib/inlet.min.js","7e389291ff8decc675a32e376e318660"],["lib/jade.js","529e365c68f8d5efc4cea18be310bd76"],["lib/less.min.js","6fd457ee80aaf9aa8758fe8a2345c970"],["lib/marked.js","9f948a81f35613d44efa9322cbaf450d"],["lib/sass.js","1263518af3f8b2090c9b08d195bd20d9"],["lib/screenlog.js","dde029b72748bbc12532b309a717c2ca"],["lib/split.js","40ac1c1fba622660e3750405b18ab0bf"],["lib/stylus.min.js","58f6030903ab52f596fb407dcd3df34f"],["lib/typescript.js","cc0882a3185037052e21fa06a38ef077"],["script.js","831c6d0ebc94afcf87adfd54acaacbc7"],["style.css","c31fb0feec7101c4cb7d0e3606e974e7"],["vendor.css","6ed94306315b8aaf789c53091c23bb4b"],["vendor.js","43e7f646f4f0c6043e24a9e958fc7e29"]];
+var precacheConfig = [["FiraCode.ttf","fa1f8c8961adca519738d9518139579c"],["changelog.html","7f40f4b9a97ca60826e7ad09e401d570"],["icon-48.png","ca68956f464ed4fd2e09c66d5edaed5f"],["index.html","fd3a70bbb629491e4fb58eb797083821"],["lib/atomizer.browser.js","451f56bc105c5ad333445998b3c085a2"],["lib/babel-polyfill.min.js","60977959048c0f5ef5aa66d6eac61eb3"],["lib/babel.min.js","77a1a84bbc2661db874c738f9b3ba375"],["lib/code-blast.js","48f8f054be45d3ad5054a7c7f87be0ff"],["lib/codemirror/mode/coffeescript/coffeescript.js","dea87b9f4c669789c4760605d947f1a9"],["lib/codemirror/mode/css/css.js","6c9ca32a78c120340e588ed3df734138"],["lib/codemirror/mode/css/gss.html","9afa6e2f3a7daa6127a3f26e2e68005c"],["lib/codemirror/mode/css/gss_test.js","e40c6fd9abdc6edc2b29e521bda726e1"],["lib/codemirror/mode/css/less.html","a35ff50857d48bb2f4df8ac737f35d64"],["lib/codemirror/mode/css/scss.html","8c96251f27727a9b23b45c41511e23a0"],["lib/codemirror/mode/haml/haml.js","9abc1679e0f54dcdd62d2326ed6133f5"],["lib/codemirror/mode/htmlembedded/htmlembedded.js","67f745ab3879bf7bc3029ac75ea3e181"],["lib/codemirror/mode/htmlmixed/htmlmixed.js","2d6915b576f267e93f0e1cf72f31af37"],["lib/codemirror/mode/javascript/javascript.js","3b2f1591e3175a24846cb182943f2a40"],["lib/codemirror/mode/javascript/json-ld.html","a2a5069194b78b6b5523cace263cab06"],["lib/codemirror/mode/javascript/typescript.html","76c2ffb883a133aa0fc5cc75ec0c56f5"],["lib/codemirror/mode/jsx/jsx.js","7bee6944931c2cc6ccd99b50fca637db"],["lib/codemirror/mode/markdown/markdown.js","30dd4984e2e929429d70cf5174b35c5d"],["lib/codemirror/mode/meta.js","6e456ea5fd8920c85d5281bd1efecb4c"],["lib/codemirror/mode/pug/pug.js","e988fd72c82f3b11836f6a06f7452436"],["lib/codemirror/mode/sass/sass.js","bd31ac70e9a457abc2789c2b83a21984"],["lib/codemirror/mode/stylus/stylus.js","81e2d281ecbb1dcf5c86857097ae60a7"],["lib/codemirror/mode/xml/xml.js","80f64aaafa6af7844d14f32f3219bb26"],["lib/codemirror/theme/3024-day.css","73c8f41583b4b71dbe1e5eac5c96f1a9"],["lib/codemirror/theme/3024-night.css","745180be9a932f24c6c0dd4ebdf5a0ed"],["lib/codemirror/theme/abcdef.css","8004cb71fd65e58bdfa64fdd55241315"],["lib/codemirror/theme/ambiance-mobile.css","256f2dd130b80c6afaa40fddf700d12a"],["lib/codemirror/theme/ambiance.css","6a200e1f3976929816cf3ac4675c810a"],["lib/codemirror/theme/base16-dark.css","84b6347918411d58d7f9b65a7ee87f65"],["lib/codemirror/theme/base16-light.css","037c7f3d16fe6d5ae2baa532e334172b"],["lib/codemirror/theme/base2tone-meadow-dark.css","f9dd12e2e51fc1575c57f3e5edc2232f"],["lib/codemirror/theme/bespin.css","cc414e4ec18bc89b3c79935b0e27fc20"],["lib/codemirror/theme/blackboard.css","cf9366960ff65c8101793bc64fe13e88"],["lib/codemirror/theme/cobalt.css","3488b576456693fd7ced2da0e10c8a16"],["lib/codemirror/theme/colorforth.css","b2ee8d2296277fc2811a7473ee4e9977"],["lib/codemirror/theme/dracula.css","e514d652ae86bfeaed34237b7d3afe44"],["lib/codemirror/theme/duotone-dark.css","02ec891b23125aaf625d978a39fd24ca"],["lib/codemirror/theme/duotone-light.css","608d11459665117d708651ce7f803fde"],["lib/codemirror/theme/eclipse.css","194369eec66630cfaf662ce5f0a193be"],["lib/codemirror/theme/elegant.css","0a4227e805a9d5f73a55dd248c1b052d"],["lib/codemirror/theme/erlang-dark.css","b5543f5273c968449760ab0d6a2af6dc"],["lib/codemirror/theme/hopscotch.css","b924ed31af30b1c68e5a01fc3c9b0553"],["lib/codemirror/theme/icecoder.css","576d776abdf7e28ea9f84e2eb161a20d"],["lib/codemirror/theme/isotope.css","7bb44bff5190c427de5ae750d6369633"],["lib/codemirror/theme/lesser-dark.css","da2c896bff035cec86fa98b6dc13f7cc"],["lib/codemirror/theme/liquibyte.css","9f37e7a4f3c02bec9bb735b78ed082d6"],["lib/codemirror/theme/material.css","11e812a3688805b5c187a6e6852bafe1"],["lib/codemirror/theme/mbo.css","55ff4bdd8a92c3dcbfd5421c532b3059"],["lib/codemirror/theme/mdn-like.css","79f8dabc5593d01d27bc824b801f9f05"],["lib/codemirror/theme/midnight.css","950e76dca6461ee1a2eac39f2d886613"],["lib/codemirror/theme/monokai.css","31c75ebee6311d49c046ffbbb91028f4"],["lib/codemirror/theme/neat.css","6b19894b9787c6791c250a95d0d4f8d6"],["lib/codemirror/theme/neo.css","2886072b53043c167e6f8765606c705c"],["lib/codemirror/theme/night.css","fe3ce7650a77e7e3887816dd7b6d880d"],["lib/codemirror/theme/panda-syntax.css","acbf94261e43c1f29c2252eb445de032"],["lib/codemirror/theme/paraiso-dark.css","3c24cee0dfac767713840b24e8359c99"],["lib/codemirror/theme/paraiso-light.css","e245bbfd22b4f61efe526ff13903f19e"],["lib/codemirror/theme/pastel-on-dark.css","48aae1a42733db57bd0a260ce0d83975"],["lib/codemirror/theme/railscasts.css","a5e7682d89da46244e5464d9572e24d8"],["lib/codemirror/theme/rubyblue.css","52bb601017a90bca522d66f6e82e73aa"],["lib/codemirror/theme/seti.css","f71668880eb1625f420ceaad670436f0"],["lib/codemirror/theme/solarized dark.css","4d05a166d713bb1ac24833061c1522d7"],["lib/codemirror/theme/solarized light.css","4d05a166d713bb1ac24833061c1522d7"],["lib/codemirror/theme/the-matrix.css","33c49ceeedafd0a08e712e465e3ad3ce"],["lib/codemirror/theme/tomorrow-night-bright.css","777d36e1c5bbfeb3bf2ca8dd607eee93"],["lib/codemirror/theme/tomorrow-night-eighties.css","5ceb5531fbe074d5190b55e8c725051e"],["lib/codemirror/theme/ttcn.css","d2cb74dfae563a10e9c286357429ea8b"],["lib/codemirror/theme/twilight.css","684040adf66ef89355cb7ebc6b54b00b"],["lib/codemirror/theme/vibrant-ink.css","f10004836fb29cc9a08c987d3e18938a"],["lib/codemirror/theme/xq-dark.css","60f162f0c4240e7352364d436b5598fa"],["lib/codemirror/theme/xq-light.css","447e80da7fe8c5c2bcf39127200cead2"],["lib/codemirror/theme/yeti.css","623dc805bc84dd6d25deef376593354e"],["lib/codemirror/theme/zenburn.css","94ad50bf3d048ed92cc513cd901dc685"],["lib/coffee-script.js","a43664b71b7b96e90046a605f6fa51a1"],["lib/emmet.js","6fff639e42ec8c00f4f4ff30b52e60df"],["lib/esprima.js","dfe041b0a8a5dda5c62ed8d2a1d3a666"],["lib/hint.min.css","0dc51e410a460622949f927dfda1bc32"],["lib/inlet.css","8242884724cfac965b53cf0a3d774c0b"],["lib/inlet.min.js","7e389291ff8decc675a32e376e318660"],["lib/jade.js","529e365c68f8d5efc4cea18be310bd76"],["lib/less.min.js","6fd457ee80aaf9aa8758fe8a2345c970"],["lib/marked.js","9f948a81f35613d44efa9322cbaf450d"],["lib/sass.js","1263518af3f8b2090c9b08d195bd20d9"],["lib/screenlog.js","dde029b72748bbc12532b309a717c2ca"],["lib/split.js","40ac1c1fba622660e3750405b18ab0bf"],["lib/stylus.min.js","58f6030903ab52f596fb407dcd3df34f"],["lib/typescript.js","cc0882a3185037052e21fa06a38ef077"],["script.js","eee81113b6fa6be92763be75915d4db4"],["style.css","2cbe0b075aa0936548d1eda9a01f86c0"],["vendor.css","6ed94306315b8aaf789c53091c23bb4b"],["vendor.js","43e7f646f4f0c6043e24a9e958fc7e29"]];
var cacheName = 'sw-precache-v3--' + (self.registration ? self.registration.scope : '');
diff --git a/app/style.css b/app/style.css
index 315d904..bfdf889 100644
--- a/app/style.css
+++ b/app/style.css
@@ -26,9 +26,11 @@ a { text-decoration: none; color: crimson; cursor: pointer; }
.fr { float: right; }
.relative { position: relative; }
.tac { text-align: center; }
+.tar { text-align: right; }
.va-m { vertical-align: middle; }
.full-width { width: 100%; }
.opacity--30 { opacity: 0.3; }
+.opacity--70 { opacity: 0.7; }
.pointer-none { pointer-events: none; }
.ml-1 { margin-left: 1rem; }
.ml-2 { margin-left: 2rem; }
@@ -234,11 +236,14 @@ body:not(.light-version).overlay-visible .main-container {
height: 18px;
}
.code-wrap__collapse-btn:before {
- content: url('data:image/svg+xml;utf8,
');
-}
-.is-minimized .code-wrap__collapse-btn:before {
+
+ /* maximize icon */
content: url('data:image/svg+xml;utf8,
');
}
+.is-maximized .code-wrap__collapse-btn:before {
+ /* minimize icon */
+ content: url('data:image/svg+xml;utf8,
');
+}
@keyframes pop-in {
from { transform: scale(0.9); opacity: 0; }
to { transform: scale(1); opacity: 1; }
@@ -855,8 +860,8 @@ transition: 0.25s ease;
}
.autocomplete__loader {
position: absolute;
- right: 10px;
- bottom: 10px;
+ right: 3px;
+ bottom: 1px;
}
@keyframes wobble {
from {
@@ -938,6 +943,19 @@ transition: 0.25s ease;
display: block;
}
+.kbd-shortcut__keys {
+ background: rgba(0,0,0,0.1);
+ border-radius: 3px;
+ padding: 3px 8px;
+ margin-right: 5px;
+ display: inline-block;
+ font-size: 0.9rem;
+ font-weight: bold;
+}
+.kbd-shortcut__details {
+ display: inline-block;
+}
+
/* Codemirror themes basic bg styles. This is here so that there is no big FOUC
while the theme CSS file is loading */
.cm-s-paraiso-dark.CodeMirror { background: #2f1e2e; color: #b9b6b0; }
diff --git a/app/script.js b/app/script.js
index 88b7c97..b445315 100644
--- a/app/script.js
+++ b/app/script.js
@@ -380,7 +380,7 @@ window.jsLibs = [
},
{
url:
- 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta/js/bootstrap.min.js',
+ 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/js/bootstrap.min.js',
label: 'Bootstrap 4β',
type: 'js'
},
@@ -401,7 +401,8 @@ window.jsLibs = [
type: 'js'
},
{
- url: 'https://cdnjs.cloudflare.com/ajax/libs/react/15.5.4/react.min.js',
+ url:
+ 'https://cdnjs.cloudflare.com/ajax/libs/react/16.2.0/cjs/react.production.min.js',
label: 'React',
type: 'js'
},
@@ -432,7 +433,7 @@ window.jsLibs = [
type: 'js'
},
{
- url: 'https://cdnjs.cloudflare.com/ajax/libs/gsap/1.19.1/TweenMax.min.js',
+ url: 'https://cdnjs.cloudflare.com/ajax/libs/gsap/1.20.3/TweenMax.min.js',
label: 'Greensock TweenMax',
type: 'js'
},
@@ -457,7 +458,7 @@ window.cssLibs = [
},
{
url:
- 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta/css/bootstrap.min.css',
+ 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/css/bootstrap.min.css',
label: 'Bootstrap 4β',
type: 'css'
},
@@ -512,9 +513,10 @@ window.cssLibs = [
// textarea-autocomplete.js
(function() {
class TextareaAutoComplete {
- constructor(textarea, filter) {
+ constructor(textarea, options) {
this.t = textarea;
- this.filter = filter;
+ this.filter = options.filter;
+ this.selectedCallback = options.selectedCallback;
var wrap = document.createElement('div');
wrap.classList.add('btn-group');
textarea.parentElement.insertBefore(wrap, textarea);
@@ -639,17 +641,25 @@ window.cssLibs = [
event.preventDefault();
} else if (event.keyCode === 13 && this.isShowingSuggestions) {
selectedItemElement = this.list.querySelector('.selected');
- this.replaceCurrentLine(selectedItemElement.dataset.url);
+ this.selectSuggestion(selectedItemElement.dataset.url);
this.closeSuggestions();
}
}
onListMouseDown(event) {
var target = event.target;
if (target.parentElement.dataset.url) {
- this.replaceCurrentLine(target.parentElement.dataset.url);
- this.closeSuggestions();
+ this.selectSuggestion(target.parentElement.dataset.url);
}
}
+
+ selectSuggestion(value) {
+ if (this.selectedCallback) {
+ this.selectedCallback.call(null, value);
+ } else {
+ this.replaceCurrentLine(value);
+ }
+ this.closeSuggestions();
+ }
}
window.TextareaAutoComplete = TextareaAutoComplete;
@@ -664,7 +674,7 @@ onboardModal, settingsModal, notificationsBtn, onboardShowInTabOptionBtn, editor
onboardDontShowInTabOptionBtn, TextareaAutoComplete, savedItemCountEl, indentationSizeValueEl,
runBtn, searchInput, consoleEl, consoleLogEl, logCountEl, fontStyleTag, fontStyleTemplate,
customEditorFontInput, cssSettingsModal, cssSettingsBtn, acssSettingsTextarea,
-globalConsoleContainerEl
+globalConsoleContainerEl, externalLibrarySearchInput, keyboardShortcutsModal
*/
/* eslint-disable no-extra-semi */
(function(alertsService) {
@@ -803,28 +813,48 @@ globalConsoleContainerEl
scope.demoFrameDocument =
frame.contentDocument || frame.contentWindow.document;
// Check all the code wrap if they are minimized or not
function updateCodeWrapCollapseStates() {
+ // This is debounced!
clearTimeout(updateCodeWrapCollapseStates.timeout);
updateCodeWrapCollapseStates.timeout = setTimeout(function() {
+ const prop = currentLayoutMode === 2 ? 'width' : 'height';
[htmlCode, cssCode, jsCode].forEach(function(el) {
- var bounds = el.getBoundingClientRect();
- if (bounds[currentLayoutMode === 2 ? 'width' : 'height'] < 100) {
+ const bounds = el.getBoundingClientRect();
+ const size = bounds[prop];
+ if (size < 100) {
el.classList.add('is-minimized');
} else {
el.classList.remove('is-minimized');
}
+ if (el.style[prop].indexOf(`100% - ${minCodeWrapSize * 2}px`) !== -1) {
+ el.classList.add('is-maximized');
+ } else {
+ el.classList.remove('is-maximized');
+ }
});
}, 50);
}
function toggleCodeWrapCollapse(codeWrapEl) {
- if (codeWrapEl.classList.contains('is-minimized')) {
+ if (
+ codeWrapEl.classList.contains('is-minimized') ||
+ codeWrapEl.classList.contains('is-maximized')
+ ) {
codeWrapEl.classList.remove('is-minimized');
+ codeWrapEl.classList.remove('is-maximized');
codeSplitInstance.setSizes([33.3, 33.3, 33.3]);
} else {
- codeSplitInstance.collapse(parseInt(codeWrapEl.dataset.codeWrapId, 10));
- codeWrapEl.classList.add('is-minimized');
+ const id = parseInt(codeWrapEl.dataset.codeWrapId, 10);
+ var arr = [
+ `${minCodeWrapSize}px`,
+ `${minCodeWrapSize}px`,
+ `${minCodeWrapSize}px`
+ ];
+ arr[id] = `calc(100% - ${minCodeWrapSize * 2}px)`;
+
+ codeSplitInstance.setSizes(arr);
+ codeWrapEl.classList.add('is-maximized');
}
}
// Returns the sizes of main code & preview panes.
@@ -988,9 +1018,9 @@ globalConsoleContainerEl
var dimensionProperty = currentLayoutMode === 2 ? 'width' : 'height';
try {
sizes = [
- +htmlCode.style[dimensionProperty].match(/([\d.]+)%/)[1],
- +cssCode.style[dimensionProperty].match(/([\d.]+)%/)[1],
- +jsCode.style[dimensionProperty].match(/([\d.]+)%/)[1]
+ htmlCode.style[dimensionProperty],
+ cssCode.style[dimensionProperty],
+ jsCode.style[dimensionProperty]
];
} catch (e) {
sizes = [33.33, 33.33, 33.33];
@@ -1285,6 +1315,7 @@ globalConsoleContainerEl
onboardModal.classList.remove('is-modal-visible');
settingsModal.classList.remove('is-modal-visible');
cssSettingsModal.classList.remove('is-modal-visible');
+ keyboardShortcutsModal.classList.remove('is-modal-visible');
toggleSavedItemsPane(false);
document.dispatchEvent(new Event('overlaysClosed'));
}
@@ -1597,7 +1628,8 @@ globalConsoleContainerEl
});
}
- function getCompleteHtml(html, css, js) {
+ /* eslint max-params: ["error", 4] */
+ function getCompleteHtml(html, css, js, isForExport) {
var externalJs = externalJsTextarea.value
.split('\n')
.reduce(function(scripts, url) {
@@ -1627,12 +1659,14 @@ globalConsoleContainerEl
externalJs +
'\n';
- contents +=
- '';
+ if (!isForExport) {
+ contents +=
+ '';
+ }
if (jsMode === JsModes.ES6) {
contents +=
@@ -1798,7 +1832,7 @@ globalConsoleContainerEl
css = result[1],
js = result[2];
- var fileContent = getCompleteHtml(html, css, js);
+ var fileContent = getCompleteHtml(html, css, js, true);
var d = new Date();
var fileName = [
@@ -2782,6 +2816,11 @@ globalConsoleContainerEl
event.preventDefault();
openSavedItemsPane();
trackEvent('ui', 'openCreationKeyboardShortcut');
+ } else if ((event.ctrlKey || event.metaKey) && event.keyCode === 191) {
+ // Ctrl/⌘ + Shift + ?
+ event.preventDefault();
+ scope.toggleModal(keyboardShortcutsModal);
+ trackEvent('ui', 'showKeyboardShortcutsShortcut');
} else if (event.keyCode === 27) {
closeAllOverlays();
}
@@ -2892,12 +2931,21 @@ globalConsoleContainerEl
externalJsTextarea.addEventListener('blur', onExternalLibChange);
externalCssTextarea.addEventListener('blur', onExternalLibChange);
- new TextareaAutoComplete(externalJsTextarea, obj =>
- obj.latest.match(/\.js$/)
- );
- new TextareaAutoComplete(externalCssTextarea, obj =>
- obj.latest.match(/\.css$/)
- );
+ new TextareaAutoComplete(externalJsTextarea, {
+ filter: obj => obj.latest.match(/\.js$/)
+ });
+ new TextareaAutoComplete(externalCssTextarea, {
+ filter: obj => obj.latest.match(/\.css$/)
+ });
+ new TextareaAutoComplete(externalLibrarySearchInput, {
+ selectedCallback: value => {
+ const textarea = value.match(/\.js$/)
+ ? externalJsTextarea
+ : externalCssTextarea;
+ textarea.value = `${textarea.value}\n${value}`;
+ externalLibrarySearchInput.value = '';
+ }
+ });
// Console header drag resize logic
var consoleHeaderDragStartY;
@@ -2965,7 +3013,7 @@ globalConsoleContainerEl
refreshEditor();
});
} else {
- utils.log('Load last unsaved item');
+ utils.log('Load last unsaved item', lastCode);
currentItem = lastCode;
refreshEditor();
}
@@ -803,28 +813,48 @@ globalConsoleContainerEl
scope.demoFrameDocument =
frame.contentDocument || frame.contentWindow.document;
- // Check all the code wrap if they are minimized or not
+ // Check all the code wrap if they are minimized or maximized
function updateCodeWrapCollapseStates() {